@@ -117,6 +117,10 @@ _HANDSHAKE_REJECTED_TLS_ERRORS = {
     "Connection was shut down by peer": "Server closed the connection during the TLS handshake",
     "alert bad record mac": "TLS alert: bad record mac",
     "tlsv1 alert internal error": "TLS alert: Internal error",
+    "illegal padding": "TLS alert: Illegal padding",
+    # Error returned by OpenSSL when the server didn't return a certificate that can work with the cipher suites
+    # enabled in the client; for example client only supports EC cipher suites but server returned an RSA certificate
+    "wrong certificate type": "Server returned wrong certificate type",
 }
 
 
