@@ -1,3 +1,4 @@
+from dataclasses import field
 from typing import Dict, Set
 
 from dataclasses import dataclass
@@ -11,9 +12,11 @@ from sslyze.server_connectivity import TlsVersionEnum
 @dataclass(frozen=True)
 class CipherSuite:
     name: str
-    openssl_name: str  # OpenSSL uses a different naming convention than the corresponding RFCs.
     is_anonymous: bool
     key_size: int
+    # OpenSSL uses a different naming convention than the corresponding RFCs, and also can have multiple names for
+    # the same cipher suites; to avoid duplicates we use compare=False
+    openssl_name: str = field(compare=False)
 
 
 # Cipher suite name mappings so we can return the RFC names, instead of the OpenSSL names
@@ -558,6 +561,16 @@ _RFC_NAME_TO_KEY_SIZE_MAPPING: Dict[str, int] = {
 }
 
 
+# TLS 1.3 cipher suites implemented in OpenSSL 1.1.1
+_TLS_1_3_CIPHER_SUITES = [
+    "TLS_AES_128_GCM_SHA256",
+    "TLS_AES_128_CCM_SHA256",
+    "TLS_AES_256_GCM_SHA384",
+    "TLS_AES_128_CCM_8_SHA256",
+    "TLS_CHACHA20_POLY1305_SHA256",
+]
+
+
 def _parse_all_cipher_suites_with_legacy_openssl(tls_version: TlsVersionEnum) -> Set[str]:
     ssl_client = LegacySslClient(ssl_version=OpenSslVersionEnum(tls_version.value))
     # Disable SRP and PSK cipher suites as they need a special setup in the client and are never used
@@ -587,47 +600,42 @@ def _parse_all_cipher_suites() -> Dict[TlsVersionEnum, Set[CipherSuite]]:
                 )
             )
 
-        # For TLS 1.2, we have to use both the legacy and modern OpenSSL to cover all cipher suites
-        cipher_suites_from_legacy_openssl = _parse_all_cipher_suites_with_legacy_openssl(TlsVersionEnum.TLS_1_2)
+    # For TLS 1.2, we have to use both the legacy and modern OpenSSL to cover all cipher suites
+    cipher_suites_from_legacy_openssl = _parse_all_cipher_suites_with_legacy_openssl(TlsVersionEnum.TLS_1_2)
 
-        ssl_client_modern = SslClient(ssl_version=OpenSslVersionEnum(TlsVersionEnum.TLS_1_2.value))
-        ssl_client_modern.set_cipher_list("ALL:COMPLEMENTOFALL:-PSK:-SRP")
-        ssl_client_modern.set_ciphersuites("")  # Disable TLS 1.3 cipher suites
-        cipher_suites_from_modern_openssl = set(ssl_client_modern.get_cipher_list())
+    ssl_client_modern = SslClient(ssl_version=OpenSslVersionEnum(TlsVersionEnum.TLS_1_2.value))
+    ssl_client_modern.set_cipher_list("ALL:COMPLEMENTOFALL:-PSK:-SRP")
+    cipher_suites_from_modern_openssl = set(ssl_client_modern.get_cipher_list())
 
-        # Combine the two sets of cipher suites
-        openssl_cipher_strings = cipher_suites_from_legacy_openssl.union(cipher_suites_from_modern_openssl)
-        tls_version_to_cipher_suites[TlsVersionEnum.TLS_1_2] = set()
-        for cipher_suite_openssl_name in openssl_cipher_strings:
-            cipher_suite_rfc_name = _OPENSSL_TO_RFC_NAMES_MAPPING[TlsVersionEnum.TLS_1_2][cipher_suite_openssl_name]
-            tls_version_to_cipher_suites[TlsVersionEnum.TLS_1_2].add(
-                CipherSuite(
-                    name=cipher_suite_rfc_name,
-                    openssl_name=cipher_suite_openssl_name,
-                    is_anonymous=True if "anon" in cipher_suite_rfc_name else False,
-                    key_size=_RFC_NAME_TO_KEY_SIZE_MAPPING[cipher_suite_rfc_name],
-                )
-            )
+    # Combine the two sets of cipher suites
+    openssl_cipher_strings = cipher_suites_from_legacy_openssl.union(cipher_suites_from_modern_openssl)
+    tls_version_to_cipher_suites[TlsVersionEnum.TLS_1_2] = set()
+    for cipher_suite_openssl_name in openssl_cipher_strings:
+        # Ignore TLS 1.3 cipher suites
+        if cipher_suite_openssl_name in _TLS_1_3_CIPHER_SUITES:
+            continue
 
-        # TLS 1.3
-        ssl_client_modern = SslClient(ssl_version=OpenSslVersionEnum(TlsVersionEnum.TLS_1_3.value))
-        ssl_client_modern.set_cipher_list("")  # Disable NON-TLS-1.3 cipher suites
-        ssl_client_modern.set_ciphersuites(
-            "TLS_AES_128_GCM_SHA256:TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:"
-            "TLS_AES_128_CCM_SHA256:TLS_AES_128_CCM_8_SHA256"
-        )  # Enable all TLS 1.3 cipher suites
-        openssl_cipher_strings = set(ssl_client_modern.get_cipher_list())
-
-        tls_version_to_cipher_suites[TlsVersionEnum.TLS_1_3] = {
+        cipher_suite_rfc_name = _OPENSSL_TO_RFC_NAMES_MAPPING[TlsVersionEnum.TLS_1_2][cipher_suite_openssl_name]
+        tls_version_to_cipher_suites[TlsVersionEnum.TLS_1_2].add(
             CipherSuite(
-                # For TLS 1.3 OpenSSL started using the official names
-                name=cipher_suite_openssl_name,
+                name=cipher_suite_rfc_name,
                 openssl_name=cipher_suite_openssl_name,
-                is_anonymous=False,
-                key_size=_RFC_NAME_TO_KEY_SIZE_MAPPING[cipher_suite_openssl_name],
+                is_anonymous=True if "anon" in cipher_suite_rfc_name else False,
+                key_size=_RFC_NAME_TO_KEY_SIZE_MAPPING[cipher_suite_rfc_name],
             )
-            for cipher_suite_openssl_name in openssl_cipher_strings
-        }
+        )
+
+    # TLS 1.3 - the list is just hardcoded
+    tls_version_to_cipher_suites[TlsVersionEnum.TLS_1_3] = {
+        CipherSuite(
+            # For TLS 1.3 OpenSSL started using the official names
+            name=cipher_suite_name,
+            openssl_name=cipher_suite_name,
+            is_anonymous=False,
+            key_size=_RFC_NAME_TO_KEY_SIZE_MAPPING[cipher_suite_name],
+        )
+        for cipher_suite_name in _TLS_1_3_CIPHER_SUITES
+    }
 
     return tls_version_to_cipher_suites
 
@@ -641,3 +649,10 @@ class CipherSuitesRepository:
         """Get the list of cipher suites supported by OpenSSL for the given SSL/TLS version.
         """
         return cls._ALL_CIPHER_SUITES[tls_version]
+
+    @classmethod
+    def get_cipher_suite_with_openssl_name(cls, tls_version: TlsVersionEnum, openssl_name: str) -> CipherSuite:
+        for cipher_suite in cls.get_all_cipher_suites(tls_version):
+            if cipher_suite.openssl_name == openssl_name:
+                return cipher_suite
+        raise ValueError(f"Could not find a cipher suite with the supplied name: {openssl_name}")
